#!/bin/sh
# test the network state, try to recover if something happens
# normally, this runs fast, in error cases it can take as long as ~15 seconds
#
# Tim Hockin

. /usr/sausalito/swatch/statecodes

# we may change this throughout the script
FINAL_RET=$AM_STATE_GREEN

# get network config
. /etc/sysconfig/network

PING="ping -q -c3 -l3"

# cop out if we're shut-out of network connectivity via ppp window
HOUR=`date +%H`
if [ -f /etc/ppp/nodial/$HOUR ]; then
        exit $FINAL_RET
fi

# make sure any interfaces that should be up are up
for a in /etc/sysconfig/network-scripts/ifcfg-*[^~]; do
	. $a
	if [ -z "$ONBOOT" -o "$ONBOOT" = "no" -o "$ONBOOT" = "false" ]; then
		continue
	fi
	
	# see that it is in ifconfig
	ifconfig | grep $DEVICE >/dev/null 2>&1
	RET=$?
	if [ "$RET" != "0" ]; then
		# hrrm, not in ifconfig - try to ifup it
		/etc/sysconfig/network-scripts/ifup $DEVICE >/dev/null 2>&1
		ifconfig | grep $DEVICE >/dev/null 2>&1
		RET=$?
		if [ "$RET" != "0" ]; then
			echo -ne "[[base-network.amIfaceIsDown,iface=$DEVICE]]"
			FINAL_RET=$AM_STATE_RED
			continue
		fi
	fi

	# ping it
	$PING $IPADDR > /dev/null 2>&1
	RET=$?
	if [ "$RET" != "0" ]; then
		# try to recover the interface
		/etc/sysconfig/network-scripts/ifdown $DEVICE >/dev/null 2>&1
		/etc/sysconfig/network-scripts/ifup $DEVICE >/dev/null 2>&1
		# try again
		$PING $IPADDR > /dev/null 2>&1
		RET=$?
		if [ "$RET" != "0" ]; then
			echo -ne "[[base-network.amIfaceIsDown,iface=$DEVICE]]"
			FINAL_RET=$AM_STATE_RED
			continue
		fi
	fi
done
		
# test the gateway
if [ -n $GATEWAY -a -n "`/sbin/route -n | grep "^0.0.0.0" 2>/dev/null`" ]; then
	$PING $GATEWAY > /dev/null 2>&1
	RET=$?
	if [ "$RET" != "0" ]; then
		# try again
		$PING $GATEWAY > /dev/null 2>&1
		RET=$?
		if [ "$RET" != "0" ]; then
			echo -ne "[[base-network.amGatewayIsUnreachable]]"
			if [ "$FINAL_RET" != "$AM_STATE_RED" ]; then
				FINAL_RET=$AM_STATE_YELLOW	
			fi
		fi
	fi
fi

if [ "$FINAL_RET" = "$AM_STATE_GREEN" ]; then
	echo -ne "[[base-network.amNetworkOK]]"
fi

exit $FINAL_RET
